@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,20 +21,24 @@
 #define GRANTLEEPRINT_H
 
 #include "kaddressbook_grantlee_export.h"
-#include <PimCommon/GenericGrantleeFormatter>
-#include <QObject>
+
+#include <GrantleeTheme/GenericFormatter>
 #include <KContacts/Addressee>
 
 namespace KAddressBookGrantlee {
-class KADDRESSBOOK_GRANTLEE_EXPORT GrantleePrint : public PimCommon::GenericGrantleeFormatter
+
+/** Grantlee-based contact printing. */
+class KADDRESSBOOK_GRANTLEE_EXPORT GrantleePrint : public GrantleeTheme::GenericFormatter
 {
-    Q_OBJECT
 public:
-    explicit GrantleePrint(QObject *parent = nullptr);
-    explicit GrantleePrint(const QString &themePath, QObject *parent = nullptr);
+    GrantleePrint();
+    explicit GrantleePrint(const QString &themePath);
     ~GrantleePrint();
 
-    QString contactsToHtml(const KContacts::Addressee::List &contacts);
+    Q_REQUIRED_RESULT QString contactsToHtml(const KContacts::Addressee::List &contacts);
+
+private:
+    void init();
 };
 }
 #endif // GRANTLEEPRINT_H
