@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@
 namespace SendLater {
 class SendLaterInfo;
 namespace SendLaterUtil {
-QDateTime updateRecurence(SendLater::SendLaterInfo *info, QDateTime dateTime);
+Q_REQUIRED_RESULT QDateTime updateRecurence(SendLater::SendLaterInfo *info, QDateTime dateTime);
 }
 }
 #endif // SENDLATERUTIL_P_H
